@@ -125,7 +125,7 @@ def finddownloadurl(driver,elementstr=""):
     return ''
 
 
-def qbseed(url,filepath,qbinfo,is_skip_checking=False,is_paused=True):
+def qbseed(url,filepath,qbinfo,is_skip_checking=False,is_paused=True,category=None):
     logger.info('正在添加资源到Qbittorrent,请稍等...')
 
     if int(qbinfo['start'])==1:
@@ -157,7 +157,7 @@ def qbseed(url,filepath,qbinfo,is_skip_checking=False,is_paused=True):
             return False
         logger.info('正在第'+str(trynum)+'次添加种子')
         try:
-            res=client.torrents_add(urls=url,save_path=filepath,is_skip_checking=is_skip_checking,is_paused=is_paused)
+            res=client.torrents_add(urls=url,save_path=filepath,is_skip_checking=is_skip_checking,is_paused=is_paused,use_auto_torrent_management=None,category=category)
         except Exception as r:
             logger.warning('添加种子进入qb出错，错误信息: %s' %(r))
             continue
